@@ -1,6 +1,6 @@
 ;;; ement-directory.el --- Public room directory support                       -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2022  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
 
 ;; Author: Adam Porter <adam@alphapapa.net>
 ;; Maintainer: Adam Porter <adam@alphapapa.net>
@@ -85,8 +85,21 @@
     (when (equal "m.space" type)
       "Spaces")))
 
+(ement-directory-define-key people-p ()
+  (pcase-let (((map ('room_id id) ('room_type type)) item)
+              ((map session) ement-directory-etc))
+    (pcase type
+      ("m.space" nil)
+      (_ (when-let ((room (cl-find id (ement-session-rooms session)
+                                   :key #'ement-room-id :test #'equal))
+                    ((ement--room-direct-p room session)))
+           (propertize "People" 'face 'ement-room-list-direct))))))
+
 (defcustom ement-directory-default-keys
-  '((joined-p)
+  '((joined-p
+     (people-p)
+     (and :name "Rooms"
+          :keys ((not people-p))))
     (space-p)
     ((size :> 10000))
     ((size :> 1000))
@@ -116,18 +129,24 @@
       " ")))
 
 (ement-directory-define-column "Name" (:max-width 25)
-  (pcase-let* (((map name ('room_type type)) item)
+  (pcase-let* (((map name ('room_id id) ('room_type type)) item)
+               ((map session) ement-directory-etc)
+               (room)
                (face (pcase type
                        ("m.space" 'ement-room-list-space)
-                       (_ 'ement-room-list-name))))
-    (propertize (or name "[unnamed]")
+                       (_ (if (and (setf room (cl-find id (ement-session-rooms session)
+                                                       :key #'ement-room-id :test #'equal))
+                                   (ement--room-direct-p room session))
+                              'ement-room-list-direct
+                            'ement-room-list-name)))))
+    (propertize (or name (ement--room-display-name room))
                 'face face)))
 
 (ement-directory-define-column "Alias" (:max-width 25)
   (pcase-let (((map ('canonical_alias alias)) item))
     (or alias "")))
 
-(ement-directory-define-column "Size" ()
+(ement-directory-define-column "Size" (:align 'right)
   (pcase-let (((map ('num_joined_members size)) item))
     (number-to-string size)))
 
@@ -296,31 +315,31 @@ APPEND-P, add ROOMS to buffer rather than replacing existing
 contents.  To be called by `ement-directory-search'."
   (declare (indent defun))
   (let (column-sizes window-start)
-    (cl-labels ((format-item
-                 ;; NOTE: We use the buffer-local variable `ement-directory-etc' rather
-                 ;; than a closure variable because the taxy-magit-section struct's format
-                 ;; table is not stored in it, and we can't reuse closures' variables.
-                 ;; (It would be good to store the format table in the taxy-magit-section
-                 ;; in the future, to make this cleaner.)
-                 (item) (gethash item (alist-get 'format-table ement-directory-etc)))
+    (cl-labels ((format-item (item)
+                  ;; NOTE: We use the buffer-local variable `ement-directory-etc' rather
+                  ;; than a closure variable because the taxy-magit-section struct's format
+                  ;; table is not stored in it, and we can't reuse closures' variables.
+                  ;; (It would be good to store the format table in the taxy-magit-section
+                  ;; in the future, to make this cleaner.)
+                  (gethash item (alist-get 'format-table ement-directory-etc)))
                 ;; NOTE: Since these functions take an "item" (which is a [room session]
                 ;; vector), they're prefixed "item-" rather than "room-".
-                (size
-                 (item) (pcase-let (((map ('num_joined_members size)) item))
-                          size))
+                (size (item)
+                  (pcase-let (((map ('num_joined_members size)) item))
+                    size))
                 (t<nil (a b) (and a (not b)))
                 (t>nil (a b) (and (not a) b))
                 (make-fn (&rest args)
-                         (apply #'make-taxy-magit-section
-                                :make #'make-fn
-                                :format-fn #'format-item
-                                ;; FIXME: Should we reuse `ement-room-list-level-indent' here?
-                                :level-indent ement-room-list-level-indent
-                                ;; :visibility-fn #'visible-p
-                                ;; :heading-indent 2
-                                :item-indent 2
-                                ;; :heading-face-fn #'heading-face
-                                args)))
+                  (apply #'make-taxy-magit-section
+                         :make #'make-fn
+                         :format-fn #'format-item
+                         ;; FIXME: Should we reuse `ement-room-list-level-indent' here?
+                         :level-indent ement-room-list-level-indent
+                         ;; :visibility-fn #'visible-p
+                         ;; :heading-indent 2
+                         :item-indent 2
+                         ;; :heading-face-fn #'heading-face
+                         args)))
       (with-current-buffer (get-buffer-create buffer-name)
         (unless (eq 'ement-directory-mode major-mode)
           ;; Don't obliterate buffer-local variables.
